@@ -62,6 +62,7 @@ QAptWorker::QAptWorker(int &argc, char **argv)
         , m_records(0)
         , m_questionBlock(0)
         , m_systemLocked(false)
+        , m_initialized(false)
 {
     new QaptworkerAdaptor(this);
 
@@ -123,24 +124,36 @@ bool QAptWorker::unlockSystem()
 
 bool QAptWorker::initializeApt()
 {
-    if (!pkgInitConfig(*_config) || !pkgInitSystem(*_config, _system)) {
-        throwInitError();
-        return false;
+    // Discard errors from past calls to initApt
+    _error->Discard();
+    if (!m_initialized) {
+        if (!pkgInitConfig(*_config) || !pkgInitSystem(*_config, _system)) {
+            throwInitError();
+            return false;
+        }
+
+        if (!m_cache) {
+            m_cache = new QApt::Cache(this);
+        }
+
+        m_initialized = true;
     }
 
-    if (!m_cache) {
-        m_cache = new QApt::Cache(this);
-    }
+    reloadCache();
+
+    return true;
+}
+
+void QAptWorker::reloadCache()
+{
     if (!m_cache->open()) {
         aptDebug() << "Cache didn't open";
         throwInitError();
-        return false;
+        return;
     }
 
     delete m_records;
     m_records = new pkgRecords(*m_cache->depCache());
-
-    return true;
 }
 
 void QAptWorker::throwInitError()
@@ -180,6 +193,8 @@ void QAptWorker::updateCache()
         return;
     }
 
+    m_timeout->stop();
+
     emit workerStarted();
     emit workerEvent(QApt::CacheUpdateStarted);
 
@@ -218,6 +233,7 @@ void QAptWorker::updateCache()
     }
 
     emit workerEvent(QApt::CacheUpdateFinished);
+    m_timeout->start();
 }
 
 void QAptWorker::cancelDownload()
@@ -234,6 +250,8 @@ void QAptWorker::commitChanges(QMap<QString, QVariant> instructionsList)
         return;
     }
 
+    m_timeout->stop();
+
     QVariantMap versionList;
 
     // Parse out the argument list and mark packages for operations
@@ -437,8 +455,9 @@ void QAptWorker::commitChanges(QMap<QString, QVariant> instructionsList)
     emit workerEvent(QApt::PackageDownloadStarted);
 
     if (fetcher.Run() != pkgAcquire::Continue) {
-        // Our fetcher will report errors for itself, but we have to send the
-        // finished signal
+        // Our fetcher will report warnings for itself, but if it fails entirely
+        // we have to send the error and finished signals
+        emit errorOccurred(QApt::FetchError, QVariantMap());
         emit workerFinished(false);
         return;
     }
@@ -461,13 +480,13 @@ void QAptWorker::commitChanges(QMap<QString, QVariant> instructionsList)
     pkgPackageManager::OrderResult res = installProgress->start(packageManager);
     bool success = (res == pkgPackageManager::Completed);
 
-    if (success) {
-        emit workerEvent(QApt::CommitChangesFinished);
-    }
+    emit workerEvent(QApt::CommitChangesFinished);
     emit workerFinished(success);
 
     delete installProgress;
     installProgress = 0;
+
+    m_timeout->start();
 }
 
 void QAptWorker::downloadArchives(const QStringList &packageStrings, const QString &dest)
@@ -477,6 +496,8 @@ void QAptWorker::downloadArchives(const QStringList &packageStrings, const QStri
         return;
     }
 
+    m_timeout->stop();
+
     emit workerStarted();
 
     initializeStatusWatcher();
@@ -535,6 +556,8 @@ void QAptWorker::downloadArchives(const QStringList &packageStrings, const QStri
         return;
     }
 
+    m_timeout->start();
+
     emit workerEvent(QApt::PackageDownloadFinished);
     emit workerFinished(true);
 }
@@ -556,6 +579,7 @@ void QAptWorker::installDebFile(const QString &fileName)
     if (arch != QLatin1String("all") &&
         arch != QString::fromStdString(_config->Find("APT::Architecture", ""))) {
         // TODO report what arch was provided vs needed
+        aptDebug() << arch << QString::fromStdString(_config->Find("APT::Architecture", ""));
         emit errorOccurred(QApt::WrongArchError, QVariantMap());
         emit workerFinished(false);
         return;
@@ -568,8 +592,8 @@ void QAptWorker::installDebFile(const QString &fileName)
     }
 
     m_dpkgProcess = new QProcess(this);
-    QString program = QLatin1Literal("dpkg") %
-                      QLatin1Literal(" -i ") % fileName;
+    QString program = QLatin1String("dpkg") %
+            QLatin1String(" -i ") % '"' % fileName % '"';
     setenv("PATH", "/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin", 1);
     setenv("DEBIAN_FRONTEND", "passthrough", 1);
     setenv("DEBCONF_PIPE", "/tmp/qapt-sock", 1);
